# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lance.org/format/namespace/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lance.org/format/namespace/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class BooleanQuery(BaseModel):
    """
    Boolean query with must, should, and must_not clauses
    """ # noqa: E501
    must: List[FtsQuery] = Field(description="Queries that must match (AND)")
    must_not: List[FtsQuery] = Field(description="Queries that must not match (NOT)")
    should: List[FtsQuery] = Field(description="Queries that should match (OR)")
    __properties: ClassVar[List[str]] = ["must", "must_not", "should"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BooleanQuery from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in must (list)
        _items = []
        if self.must:
            for _item_must in self.must:
                if _item_must:
                    _items.append(_item_must.to_dict())
            _dict['must'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in must_not (list)
        _items = []
        if self.must_not:
            for _item_must_not in self.must_not:
                if _item_must_not:
                    _items.append(_item_must_not.to_dict())
            _dict['must_not'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in should (list)
        _items = []
        if self.should:
            for _item_should in self.should:
                if _item_should:
                    _items.append(_item_should.to_dict())
            _dict['should'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BooleanQuery from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "must": [FtsQuery.from_dict(_item) for _item in obj["must"]] if obj.get("must") is not None else None,
            "must_not": [FtsQuery.from_dict(_item) for _item in obj["must_not"]] if obj.get("must_not") is not None else None,
            "should": [FtsQuery.from_dict(_item) for _item in obj["should"]] if obj.get("should") is not None else None
        })
        return _obj

from lance_namespace_urllib3_client.models.fts_query import FtsQuery
# TODO: Rewrite to not use raise_errors
BooleanQuery.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lance.org/format/namespace/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lance.org/format/namespace/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.models.analyze_table_query_plan_request import AnalyzeTableQueryPlanRequest

class TestAnalyzeTableQueryPlanRequest(unittest.TestCase):
    """AnalyzeTableQueryPlanRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalyzeTableQueryPlanRequest:
        """Test AnalyzeTableQueryPlanRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalyzeTableQueryPlanRequest`
        """
        model = AnalyzeTableQueryPlanRequest()
        if include_optional:
            return AnalyzeTableQueryPlanRequest(
                id = [
                    ''
                    ],
                bypass_vector_index = True,
                columns = lance_namespace_urllib3_client.models.query_table_request_columns.QueryTableRequest_columns(
                    column_names = [
                        ''
                        ], 
                    column_aliases = {
                        'key' : ''
                        }, ),
                distance_type = '',
                ef = 0,
                fast_search = True,
                filter = '',
                full_text_query = lance_namespace_urllib3_client.models.query_table_request_full_text_query.QueryTableRequest_full_text_query(
                    string_query = lance_namespace_urllib3_client.models.string_fts_query.StringFtsQuery(
                        columns = [
                            ''
                            ], 
                        query = '', ), 
                    structured_query = lance_namespace_urllib3_client.models.structured_fts_query.StructuredFtsQuery(
                        query = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                            match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                boost = 1.337, 
                                column = '', 
                                fuzziness = 0, 
                                max_expansions = 0, 
                                operator = '', 
                                prefix_length = 0, 
                                terms = '', ), 
                            phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                                column = '', 
                                slop = 0, 
                                terms = '', ), 
                            boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                                positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                                    multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                        match_queries = [
                                            lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                                column = '', 
                                                fuzziness = 0, 
                                                max_expansions = 0, 
                                                operator = '', 
                                                prefix_length = 0, 
                                                terms = '', )
                                            ], ), 
                                    boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                        must = [
                                            
                                            ], 
                                        must_not = [
                                            
                                            ], 
                                        should = [
                                            
                                            ], ), ), 
                                negative = , 
                                negative_boost = 1.337, ), 
                            multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                match_queries = [
                                    
                                    ], ), 
                            boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                must = [
                                    
                                    ], 
                                must_not = [
                                    
                                    ], 
                                should = [
                                    
                                    ], ), ), ), ),
                k = 0,
                lower_bound = 1.337,
                nprobes = 0,
                offset = 0,
                prefilter = True,
                refine_factor = 0,
                upper_bound = 1.337,
                vector = lance_namespace_urllib3_client.models.query_table_request_vector.QueryTableRequest_vector(
                    single_vector = [
                        1.337
                        ], 
                    multi_vector = [
                        [
                            1.337
                            ]
                        ], ),
                vector_column = '',
                version = 0,
                with_row_id = True
            )
        else:
            return AnalyzeTableQueryPlanRequest(
                k = 0,
                vector = lance_namespace_urllib3_client.models.query_table_request_vector.QueryTableRequest_vector(
                    single_vector = [
                        1.337
                        ], 
                    multi_vector = [
                        [
                            1.337
                            ]
                        ], ),
        )
        """

    def testAnalyzeTableQueryPlanRequest(self):
        """Test AnalyzeTableQueryPlanRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lance.org/format/namespace/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lance.org/format/namespace/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.api.index_api import IndexApi


class TestIndexApi(unittest.TestCase):
    """IndexApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IndexApi()

    def tearDown(self) -> None:
        pass

    def test_create_table_index(self) -> None:
        """Test case for create_table_index

        Create an index on a table
        """
        pass

    def test_create_table_scalar_index(self) -> None:
        """Test case for create_table_scalar_index

        Create a scalar index on a table
        """
        pass

    def test_describe_table_index_stats(self) -> None:
        """Test case for describe_table_index_stats

        Get table index statistics
        """
        pass

    def test_drop_table_index(self) -> None:
        """Test case for drop_table_index

        Drop a specific index
        """
        pass

    def test_list_table_indices(self) -> None:
        """Test case for list_table_indices

        List indexes on a table
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lance.org/format/namespace/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lance.org/format/namespace/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from lance_namespace_urllib3_client.models.alter_transaction_set_property import AlterTransactionSetProperty
from lance_namespace_urllib3_client.models.alter_transaction_set_status import AlterTransactionSetStatus
from lance_namespace_urllib3_client.models.alter_transaction_unset_property import AlterTransactionUnsetProperty
from typing import Optional, Set
from typing_extensions import Self

class AlterTransactionAction(BaseModel):
    """
    A single action that could be performed to alter a transaction. This action holds the model definition for all types of specific actions models, this is to minimize difference and compatibility issue across codegen in different languages. When used, only one of the actions should be non-null for each action. If you would like to perform multiple actions, set a list of actions in the AlterTransactionRequest. 
    """ # noqa: E501
    set_status_action: Optional[AlterTransactionSetStatus] = Field(default=None, alias="setStatusAction")
    set_property_action: Optional[AlterTransactionSetProperty] = Field(default=None, alias="setPropertyAction")
    unset_property_action: Optional[AlterTransactionUnsetProperty] = Field(default=None, alias="unsetPropertyAction")
    __properties: ClassVar[List[str]] = ["setStatusAction", "setPropertyAction", "unsetPropertyAction"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AlterTransactionAction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of set_status_action
        if self.set_status_action:
            _dict['setStatusAction'] = self.set_status_action.to_dict()
        # override the default output from pydantic by calling `to_dict()` of set_property_action
        if self.set_property_action:
            _dict['setPropertyAction'] = self.set_property_action.to_dict()
        # override the default output from pydantic by calling `to_dict()` of unset_property_action
        if self.unset_property_action:
            _dict['unsetPropertyAction'] = self.unset_property_action.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AlterTransactionAction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "setStatusAction": AlterTransactionSetStatus.from_dict(obj["setStatusAction"]) if obj.get("setStatusAction") is not None else None,
            "setPropertyAction": AlterTransactionSetProperty.from_dict(obj["setPropertyAction"]) if obj.get("setPropertyAction") is not None else None,
            "unsetPropertyAction": AlterTransactionUnsetProperty.from_dict(obj["unsetPropertyAction"]) if obj.get("unsetPropertyAction") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lance.org/format/namespace/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lance.org/format/namespace/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class ErrorResponse(BaseModel):
    """
    Common JSON error response model
    """ # noqa: E501
    error: Optional[StrictStr] = Field(default=None, description="A brief, human-readable message about the error.")
    code: Annotated[int, Field(strict=True, ge=0)] = Field(description="Lance Namespace error code identifying the error type.  Error codes:   0 - Unsupported: Operation not supported by this backend   1 - NamespaceNotFound: The specified namespace does not exist   2 - NamespaceAlreadyExists: A namespace with this name already exists   3 - NamespaceNotEmpty: Namespace contains tables or child namespaces   4 - TableNotFound: The specified table does not exist   5 - TableAlreadyExists: A table with this name already exists   6 - TableIndexNotFound: The specified table index does not exist   7 - TableIndexAlreadyExists: A table index with this name already exists   8 - TableTagNotFound: The specified table tag does not exist   9 - TableTagAlreadyExists: A table tag with this name already exists   10 - TransactionNotFound: The specified transaction does not exist   11 - TableVersionNotFound: The specified table version does not exist   12 - TableColumnNotFound: The specified table column does not exist   13 - InvalidInput: Malformed request or invalid parameters   14 - ConcurrentModification: Optimistic concurrency conflict   15 - PermissionDenied: User lacks permission for this operation   16 - Unauthenticated: Authentication credentials are missing or invalid   17 - ServiceUnavailable: Service is temporarily unavailable   18 - Internal: Unexpected server/implementation error   19 - InvalidTableState: Table is in an invalid state for the operation   20 - TableSchemaValidationError: Table schema validation failed ")
    detail: Optional[StrictStr] = Field(default=None, description="An optional human-readable explanation of the error. This can be used to record additional information such as stack trace. ")
    instance: Optional[StrictStr] = Field(default=None, description="A string that identifies the specific occurrence of the error. This can be a URI, a request or response ID, or anything that the implementation can recognize to trace specific occurrence of the error. ")
    __properties: ClassVar[List[str]] = ["error", "code", "detail", "instance"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ErrorResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ErrorResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "error": obj.get("error"),
            "code": obj.get("code"),
            "detail": obj.get("detail"),
            "instance": obj.get("instance")
        })
        return _obj





# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lance.org/format/namespace/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lance.org/format/namespace/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.models.boost_query import BoostQuery

class TestBoostQuery(unittest.TestCase):
    """BoostQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BoostQuery:
        """Test BoostQuery
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BoostQuery`
        """
        model = BoostQuery()
        if include_optional:
            return BoostQuery(
                positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                    match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                        boost = 1.337, 
                        column = '', 
                        fuzziness = 0, 
                        max_expansions = 0, 
                        operator = '', 
                        prefix_length = 0, 
                        terms = '', ), 
                    phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                        column = '', 
                        slop = 0, 
                        terms = '', ), 
                    boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                        positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                            multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                match_queries = [
                                    lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                        column = '', 
                                        fuzziness = 0, 
                                        max_expansions = 0, 
                                        operator = '', 
                                        prefix_length = 0, 
                                        terms = '', )
                                    ], ), 
                            boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                must = [
                                    
                                    ], 
                                must_not = [
                                    
                                    ], 
                                should = [
                                    
                                    ], ), ), 
                        negative = , 
                        negative_boost = 1.337, ), 
                    multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                        match_queries = [
                            
                            ], ), 
                    boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                        must = [
                            
                            ], 
                        must_not = [
                            
                            ], 
                        should = [
                            
                            ], ), ),
                negative = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                    match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                        boost = 1.337, 
                        column = '', 
                        fuzziness = 0, 
                        max_expansions = 0, 
                        operator = '', 
                        prefix_length = 0, 
                        terms = '', ), 
                    phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                        column = '', 
                        slop = 0, 
                        terms = '', ), 
                    boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                        positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                            multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                match_queries = [
                                    lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                        column = '', 
                                        fuzziness = 0, 
                                        max_expansions = 0, 
                                        operator = '', 
                                        prefix_length = 0, 
                                        terms = '', )
                                    ], ), 
                            boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                must = [
                                    
                                    ], 
                                must_not = [
                                    
                                    ], 
                                should = [
                                    
                                    ], ), ), 
                        negative = , 
                        negative_boost = 1.337, ), 
                    multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                        match_queries = [
                            
                            ], ), 
                    boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                        must = [
                            
                            ], 
                        must_not = [
                            
                            ], 
                        should = [
                            
                            ], ), ),
                negative_boost = 1.337
            )
        else:
            return BoostQuery(
                positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                    match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                        boost = 1.337, 
                        column = '', 
                        fuzziness = 0, 
                        max_expansions = 0, 
                        operator = '', 
                        prefix_length = 0, 
                        terms = '', ), 
                    phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                        column = '', 
                        slop = 0, 
                        terms = '', ), 
                    boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                        positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                            multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                match_queries = [
                                    lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                        column = '', 
                                        fuzziness = 0, 
                                        max_expansions = 0, 
                                        operator = '', 
                                        prefix_length = 0, 
                                        terms = '', )
                                    ], ), 
                            boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                must = [
                                    
                                    ], 
                                must_not = [
                                    
                                    ], 
                                should = [
                                    
                                    ], ), ), 
                        negative = , 
                        negative_boost = 1.337, ), 
                    multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                        match_queries = [
                            
                            ], ), 
                    boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                        must = [
                            
                            ], 
                        must_not = [
                            
                            ], 
                        should = [
                            
                            ], ), ),
                negative = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                    match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                        boost = 1.337, 
                        column = '', 
                        fuzziness = 0, 
                        max_expansions = 0, 
                        operator = '', 
                        prefix_length = 0, 
                        terms = '', ), 
                    phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                        column = '', 
                        slop = 0, 
                        terms = '', ), 
                    boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                        positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                            multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                match_queries = [
                                    lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                        column = '', 
                                        fuzziness = 0, 
                                        max_expansions = 0, 
                                        operator = '', 
                                        prefix_length = 0, 
                                        terms = '', )
                                    ], ), 
                            boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                must = [
                                    
                                    ], 
                                must_not = [
                                    
                                    ], 
                                should = [
                                    
                                    ], ), ), 
                        negative = , 
                        negative_boost = 1.337, ), 
                    multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                        match_queries = [
                            
                            ], ), 
                    boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                        must = [
                            
                            ], 
                        must_not = [
                            
                            ], 
                        should = [
                            
                            ], ), ),
        )
        """

    def testBoostQuery(self):
        """Test BoostQuery"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lance.org/format/namespace/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lance.org/format/namespace/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.models.explain_table_query_plan_request import ExplainTableQueryPlanRequest

class TestExplainTableQueryPlanRequest(unittest.TestCase):
    """ExplainTableQueryPlanRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExplainTableQueryPlanRequest:
        """Test ExplainTableQueryPlanRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExplainTableQueryPlanRequest`
        """
        model = ExplainTableQueryPlanRequest()
        if include_optional:
            return ExplainTableQueryPlanRequest(
                id = [
                    ''
                    ],
                query = lance_namespace_urllib3_client.models.query_table_request.QueryTableRequest(
                    id = [
                        ''
                        ], 
                    bypass_vector_index = True, 
                    columns = lance_namespace_urllib3_client.models.query_table_request_columns.QueryTableRequest_columns(
                        column_names = [
                            ''
                            ], 
                        column_aliases = {
                            'key' : ''
                            }, ), 
                    distance_type = '', 
                    ef = 0, 
                    fast_search = True, 
                    filter = '', 
                    full_text_query = lance_namespace_urllib3_client.models.query_table_request_full_text_query.QueryTableRequest_full_text_query(
                        string_query = lance_namespace_urllib3_client.models.string_fts_query.StringFtsQuery(
                            query = '', ), 
                        structured_query = lance_namespace_urllib3_client.models.structured_fts_query.StructuredFtsQuery(
                            query = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                                match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                    boost = 1.337, 
                                    column = '', 
                                    fuzziness = 0, 
                                    max_expansions = 0, 
                                    operator = '', 
                                    prefix_length = 0, 
                                    terms = '', ), 
                                phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                                    column = '', 
                                    slop = 0, 
                                    terms = '', ), 
                                boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                                    positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                                        multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                            match_queries = [
                                                lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                                    column = '', 
                                                    fuzziness = 0, 
                                                    max_expansions = 0, 
                                                    operator = '', 
                                                    prefix_length = 0, 
                                                    terms = '', )
                                                ], ), 
                                        boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                            must = [
                                                
                                                ], 
                                            must_not = [
                                                
                                                ], 
                                            should = [
                                                
                                                ], ), ), 
                                    negative = , 
                                    negative_boost = 1.337, ), 
                                multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                    match_queries = [
                                        
                                        ], ), 
                                boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                    must = [
                                        
                                        ], 
                                    must_not = [
                                        
                                        ], 
                                    should = [
                                        
                                        ], ), ), ), ), 
                    k = 0, 
                    lower_bound = 1.337, 
                    nprobes = 0, 
                    offset = 0, 
                    prefilter = True, 
                    refine_factor = 0, 
                    upper_bound = 1.337, 
                    vector = lance_namespace_urllib3_client.models.query_table_request_vector.QueryTableRequest_vector(
                        single_vector = [
                            1.337
                            ], 
                        multi_vector = [
                            [
                                1.337
                                ]
                            ], ), 
                    vector_column = '', 
                    version = 0, 
                    with_row_id = True, ),
                verbose = True
            )
        else:
            return ExplainTableQueryPlanRequest(
                query = lance_namespace_urllib3_client.models.query_table_request.QueryTableRequest(
                    id = [
                        ''
                        ], 
                    bypass_vector_index = True, 
                    columns = lance_namespace_urllib3_client.models.query_table_request_columns.QueryTableRequest_columns(
                        column_names = [
                            ''
                            ], 
                        column_aliases = {
                            'key' : ''
                            }, ), 
                    distance_type = '', 
                    ef = 0, 
                    fast_search = True, 
                    filter = '', 
                    full_text_query = lance_namespace_urllib3_client.models.query_table_request_full_text_query.QueryTableRequest_full_text_query(
                        string_query = lance_namespace_urllib3_client.models.string_fts_query.StringFtsQuery(
                            query = '', ), 
                        structured_query = lance_namespace_urllib3_client.models.structured_fts_query.StructuredFtsQuery(
                            query = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                                match = lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                    boost = 1.337, 
                                    column = '', 
                                    fuzziness = 0, 
                                    max_expansions = 0, 
                                    operator = '', 
                                    prefix_length = 0, 
                                    terms = '', ), 
                                phrase = lance_namespace_urllib3_client.models.phrase_query.PhraseQuery(
                                    column = '', 
                                    slop = 0, 
                                    terms = '', ), 
                                boost = lance_namespace_urllib3_client.models.boost_query.BoostQuery(
                                    positive = lance_namespace_urllib3_client.models.fts_query.FtsQuery(
                                        multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                            match_queries = [
                                                lance_namespace_urllib3_client.models.match_query.MatchQuery(
                                                    column = '', 
                                                    fuzziness = 0, 
                                                    max_expansions = 0, 
                                                    operator = '', 
                                                    prefix_length = 0, 
                                                    terms = '', )
                                                ], ), 
                                        boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                            must = [
                                                
                                                ], 
                                            must_not = [
                                                
                                                ], 
                                            should = [
                                                
                                                ], ), ), 
                                    negative = , 
                                    negative_boost = 1.337, ), 
                                multi_match = lance_namespace_urllib3_client.models.multi_match_query.MultiMatchQuery(
                                    match_queries = [
                                        
                                        ], ), 
                                boolean = lance_namespace_urllib3_client.models.boolean_query.BooleanQuery(
                                    must = [
                                        
                                        ], 
                                    must_not = [
                                        
                                        ], 
                                    should = [
                                        
                                        ], ), ), ), ), 
                    k = 0, 
                    lower_bound = 1.337, 
                    nprobes = 0, 
                    offset = 0, 
                    prefilter = True, 
                    refine_factor = 0, 
                    upper_bound = 1.337, 
                    vector = lance_namespace_urllib3_client.models.query_table_request_vector.QueryTableRequest_vector(
                        single_vector = [
                            1.337
                            ], 
                        multi_vector = [
                            [
                                1.337
                                ]
                            ], ), 
                    vector_column = '', 
                    version = 0, 
                    with_row_id = True, ),
        )
        """

    def testExplainTableQueryPlanRequest(self):
        """Test ExplainTableQueryPlanRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
